@@ -1,5 +1,4 @@
-use crate::AddAsHeader;
-use http::request::Builder;
+use crate::headers::{self, Header};
 
 #[derive(Debug, Clone, Copy, PartialEq, Eq)]
 pub struct ContentType<'a>(&'a str);
@@ -14,12 +13,6 @@ impl<'a> ContentType<'a> {
     }
 }
 
-impl<'a> AddAsHeader for ContentType<'a> {
-    fn add_as_header(&self, builder: Builder) -> Builder {
-        builder.header(http::header::CONTENT_TYPE, self.0)
-    }
-}
-
 impl<'a, S> From<S> for ContentType<'a>
 where
     S: Into<&'a str>,
@@ -28,3 +21,13 @@ where
         Self(s.into())
     }
 }
+
+impl<'a> Header for ContentType<'a> {
+    fn name(&self) -> headers::HeaderName {
+        http::header::CONTENT_TYPE.into()
+    }
+
+    fn value(&self) -> headers::HeaderValue {
+        self.0.to_owned().into()
+    }
+}
