@@ -1,6 +1,4 @@
-use crate::headers::*;
-use crate::AddAsHeader;
-use http::request::Builder;
+use crate::headers::{self, Header};
 use std::time::Duration;
 
 #[derive(Debug, Clone)]
@@ -9,14 +7,19 @@ pub enum LeaseDuration {
     Seconds(u8),
 }
 
-impl AddAsHeader for LeaseDuration {
-    fn add_as_header(&self, builder: Builder) -> Builder {
+impl Header for LeaseDuration {
+    fn name(&self) -> headers::HeaderName {
+        headers::LEASE_DURATION.into()
+    }
+
+    fn value(&self) -> headers::HeaderValue {
         match self {
-            LeaseDuration::Infinite => builder.header(LEASE_DURATION, "-1"),
+            LeaseDuration::Infinite => "-1".to_owned(),
             LeaseDuration::Seconds(seconds) => {
-                builder.header(LEASE_DURATION, &format!("{}", seconds))
+                format!("{}", seconds)
             }
         }
+        .into()
     }
 }
 
