@@ -1,10 +1,7 @@
-use super::BA512Range;
-use crate::errors::ParseError;
-use crate::AddAsHeader;
-use http::request::Builder;
+use crate::headers::{AsHeaders, HeaderName, HeaderValue};
+use crate::ParseError;
 use std::convert::From;
 use std::fmt;
-use std::num::ParseIntError;
 use std::str::FromStr;
 
 #[derive(Debug, Copy, Clone, PartialEq)]
@@ -27,12 +24,15 @@ impl Range {
     }
 }
 
-impl<'a> From<&'a BA512Range> for Range {
-    fn from(ba: &'a BA512Range) -> Range {
-        Range {
-            start: ba.start(),
-            end: ba.end(),
+impl AsHeaders for Range {
+    type Iter = std::vec::IntoIter<(HeaderName, HeaderValue)>;
+
+    fn as_headers(&self) -> Self::Iter {
+        let mut headers = vec![("x-ms-range".into(), format!("{}", self).into())];
+        if self.len() < 1024 * 1024 * 4 {
+            headers.push(("x-ms-range-get-content-crc64".into(), "true".into()));
         }
+        headers.into_iter()
     }
 }
 
@@ -63,18 +63,16 @@ impl From<std::ops::Range<usize>> for Range {
     }
 }
 
-impl From<ParseIntError> for ParseError {
-    fn from(pie: ParseIntError) -> ParseError {
-        ParseError::ParseIntError(pie)
-    }
-}
-
 impl FromStr for Range {
     type Err = ParseError;
-    fn from_str(s: &str) -> Result<Range, ParseError> {
+    fn from_str(s: &str) -> Result<Range, Self::Err> {
         let v = s.split('/').collect::<Vec<&str>>();
         if v.len() != 2 {
-            return Err(ParseError::SplitNotFound);
+            return Err(ParseError::TokenNotFound {
+                item: "Range",
+                token: "/".to_owned(),
+                full: s.to_owned(),
+            });
         }
 
         let cp_start = v[0].parse::<u64>()?;
@@ -93,19 +91,6 @@ impl fmt::Display for Range {
     }
 }
 
-impl<'a> AddAsHeader for Range {
-    // here we ask for the CRC64 value if we can (that is,
-    // the range is smaller than 4MB).
-    fn add_as_header(&self, builder: Builder) -> Builder {
-        let builder = builder.header("x-ms-range", &format!("{}", self));
-        if self.len() < 1024 * 1024 * 4 {
-            builder.header("x-ms-range-get-content-crc64", "true")
-        } else {
-            builder
-        }
-    }
-}
-
 #[cfg(test)]
 mod test {
     use super::*;
@@ -119,15 +104,22 @@ mod test {
     }
 
     #[test]
-    #[should_panic(expected = "ParseIntError(ParseIntError { kind: InvalidDigit })")]
     fn test_range_parse_panic_1() {
-        "abba/2000".parse::<Range>().unwrap();
+        let err = "abba/2000".parse::<Range>().unwrap_err();
+        assert!(matches!(err, ParseError::Int(_)));
     }
 
     #[test]
-    #[should_panic(expected = "SplitNotFound")]
     fn test_range_parse_panic_2() {
-        "1000-2000".parse::<Range>().unwrap();
+        let err = "1000-2000".parse::<Range>().unwrap_err();
+        assert_eq!(
+            err,
+            ParseError::TokenNotFound {
+                item: "Range",
+                token: "/".to_string(),
+                full: "1000-2000".to_string()
+            }
+        );
     }
 
     #[test]
